#!/bin/sh

cd /home/user/imagemagick/

# This is the weather URL.  Change this to your URL
WEATHERURL="http://weather.yahoo.com/united-states/new-york/rochester-12763346/?unit=f"

#unit used above.  If C, use the other.
UNIT="F"
#UNIT="C"

# Current temperature must be above this to use "summer" theme
USESUMMER=55
#USESUMMER=28

# Current temperature must be below this to use "winter" theme
USEWINTER=35
#USEWINTER=3

# How often we update if NOT on wifi (6 hours)
# Set this to 0 if you want it to ignore if on wifi vs 2/3G
CHECKINT=21600

######## You shouldn't need to change anything below here ###############

# Name of our temporary file from Yahoo
TEMPNAME="ywtemp.htm"

#seet if we have a wifi connection
wifion=`/sbin/ifconfig wlan0 | grep -i "inet addr" | wc -l`

# if not on wifi and we have a previous file, check it to see
# if we want to update again this soon while on 2G/3G data.
if [ ! $CHECKINT -eq 0  ] && [ ! $wifion -eq 1  ] && [ -e $TEMPNAME ]
then
    # check time stamp on the existing temp file
    cur_timestamp=`date +%s`
    my_stat=`stat -t $TEMPNAME 2>/dev/null`
    read name size blocks unk uid gid dev inode links unk2 unk3 last_access last_mod last_change ioblock << ENDHERE
    $(echo $my_stat)
ENDHERE

    #Compare that stamp to the current time
    if [ $last_mod ]
    then
        time_diff=`expr $cur_timestamp - $last_mod`
        if [ $time_diff -lt $CHECKINT ]
        then    
	    # We updated recently enough and are not on wifi
	    # Tell QBW (or caller) we left without update.
	    exit 1
        fi
    fi  
fi

# We are updating!  Getting all the necessary info.
# That's where you should change url to your yahoo weather web page.
wget --user-agent="" -q -t 1 -T 10 -O "$TEMPNAME" "$WEATHERURL" || exit 2

# That's where we get the image associated with the weather.
wget --user-agent="" -q -t 1 -T 10 -O "ywtemp.png" `grep 'forecast-icon.*http.*png' ywtemp.htm | grep -o http*[a-zA-Z0-9\\.\\-\\\\_/\\:]*.png | grep -m 1 http` 

#Get all of out temperatures (and current time/date) into variables
HighTemp=`grep 'yw-forecast' $TEMPNAME | grep -o 'High[:].[-0-9][-0-9]*' |head -1 | grep -o '[-0-9][-0-9]*'`
LowTemp=`grep 'yw-forecast' $TEMPNAME | grep -o 'Low[:].[-0-9][-0-9]*' |head -1 | grep -o '[-0-9][-0-9]*'`
CurTemp=`grep 'yw-forecast' $TEMPNAME | grep -o 'yw-temp..[-0-9]*' | head -1 |grep -o 'temp..[-0-9]*' | grep -o '[-0-9][-0-9]*'`
FiveTemps=`grep "fiveday-temps" ywtemp.htm  | sed -e "s#</div>#\n#g" | sed -e "s/&#.*>/ /" | grep -o "[0-9]* Low: [0-9]*" | sed -e "s# Low: #/#" |head -5`
FiveFore=`grep "fivedayforecast" ywtemp.htm |  sed -e "s#</div>#\n#g" | grep -o "[a-z|A-Z| ]*$" | head -5 `

CurDate=`date `

#echo "Current: " $CurTemp F " High: " $HighTemp F  " Low: " $LowTemp F 
#echo "5day: " $FiveTemps


# Summer scenario.
if [ $CurTemp -gt  $USESUMMER ]
then 
#echo "Using Summer theme"
convert summer.png \
-page +600+15 -background transparent -fill grey -pointsize 12 -strokewidth 1  -stroke grey  label:"$CurDate" \
-page +550+30 -background transparent -fill white -font fonts/2toon2v2.ttf -pointsize 140 -strokewidth 2  -stroke black  label:"$CurTemp$UNIT" \
-page +400+345 -background transparent -fill orange -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"High:$HighTemp$UNIT" \
-page +26+345 -background transparent -fill "#2df2a879ffff" -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"Low:$LowTemp$UNIT" \
-page +550+160 -background transparent -fill "#2df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"Forecast:\n$FiveTemps" \
-page +630+160 -background transparent -fill "#4df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"\n$FiveFore" \
-flatten -draw "image over 30,20 425,300 'ywtemp.png'" lockslider.png

# Winter scenario.
else
if [ $CurTemp -lt  $USEWINTER ]
then
#echo "Using Winter theme"
convert winter.png \
-page +600+15 -background transparent -fill grey -pointsize 12 -strokewidth 1  -stroke grey  label:"$CurDate" \
-page +550+60 -background transparent -fill white -font fonts/2toon2v2.ttf -pointsize 140 -strokewidth 2  -stroke black  label:"$CurTemp$UNIT" \
-page +400+345 -background transparent -fill orange -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"High:$HighTemp$UNIT" \
-page +26+345 -background transparent -fill "#2df2a879ffff" -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"Low:$LowTemp$UNIT" \
-page +550+160 -background transparent -fill "#2df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"Forecast:\n$FiveTemps" \
-page +630+160 -background transparent -fill "#4df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"\n$FiveFore" \
-flatten -draw "image over 30,20 425,300 'ywtemp.png'" lockslider.png

# not summer or winter scenario.
else
#echo "Using Space theme"
convert space.png \
-page +600+15 -background transparent -fill grey -pointsize 12 -strokewidth 1  -stroke grey  label:"$CurDate" \
-page +550+100 -background transparent -fill white -font fonts/2toon2v2.ttf -pointsize 140 -strokewidth 2  -stroke black  label:"$CurTemp$UNIT" \
-page +400+345 -background transparent -fill orange -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"High:$HighTemp$UNIT" \
-page +26+345 -background transparent -fill "#2df2a879ffff" -font fonts/2toon2v2.ttf -pointsize 90 -strokewidth 2  -stroke black  label:"Low:$LowTemp$UNIT" \
-page +550+160 -background transparent -fill "#2df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"Forecast:\n$FiveTemps" \
-page +630+160 -background transparent -fill "#4df2a879ffff" -font fonts/tahoma.ttf -pointsize 25 -strokewidth 2  -stroke black  label:"\n$FiveFore" \
-flatten -draw "image over 30,20 425,300 'ywtemp.png'" lockslider.png

fi
fi

# Making new slider.
cp slider.png /etc/hildon/theme/images/LockSliderThumbPortrait.png
cp slider.png /etc/hildon/theme/images/LockSliderThumb.png
# making other stuff disappear.
cp LockSliderTop.png /etc/hildon/theme/images/LockSliderTop.png
cp LockSliderRight.png  /etc/hildon/theme/images/LockSliderRight.png
cp LockSliderLeft.png /etc/hildon/theme/images/LockSliderLeft.png
cp LockSliderBottom.png /etc/hildon/theme/images/LockSliderBottom.png
# Moving the final background to your current theme directory.
cp lockslider.png /etc/hildon/theme/backgrounds/

exit 0
